# coding: utf8
"""
All wordforms are extracted from Norsk Ordbank in Norwegian Bokmål 2005
(CLARINO NB - Språkbanken), Nasjonalbiblioteket, Norway:
https://www.nb.no/sprakbanken/show?serial=oai%3Anb.no%3Asbr-5&lang=en
License:
Creative_Commons-BY (CC-BY) (https://creativecommons.org/licenses/by/4.0/)
"""

from __future__ import unicode_literals

ADVERBS_WORDFORMS = {
'à jour': ('à jour',),
'à la carte': ('à la carte',),
'à la grecque': ('à la grecque',),
'à la mode': ('à la mode',),
'òg': ('òg',),
'a': ('a',),
'a cappella': ('a cappella',),
'a conto': ('a conto',),
'a konto': ('a konto',),
'a posteriori': ('a posteriori',),
'a prima vista': ('a prima vista',),
'a priori': ('a priori',),
'a tempo': ('a tempo',),
'a verbo': ('a verbo',),
'a viso': ('a viso',),
'a vista': ('a vista',),
'ad absurdum': ('ad absurdum',),
'ad acta': ('ad acta',),
'ad hoc': ('ad hoc',),
'ad infinitum': ('ad infinitum',),
'ad notam': ('ad notam',),
'ad undas': ('ad undas',),
'adagio': ('adagio',),
'akkurat': ('akkurat',),
'al fresco': ('al fresco',),
'al secco': ('al secco',),
'aldeles': ('aldeles',),
'alders tid': ('alders tid',),
'aldri': ('aldri',),
'aleine': ('aleine',),
'alene': ('alene',),
'alias': ('alias',),
'allegretto': ('allegretto',),
'allegro': ('allegro',),
'aller': ('aller',),
'allerede': ('allerede',),
'allikevel': ('allikevel',),
'alltid': ('alltid',),
'alltids': ('alltids',),
'alt': ('alt',),
'altfor': ('altfor',),
'altså': ('altså',),
'amok': ('amok',),
'an': ('an',),
'ana': ('ana',),
'andante': ('andante',),
'andantino': ('andantino',),
'andelsvis': ('andelsvis',),
'andfares': ('andfares',),
'andføttes': ('andføttes',),
'annetsteds': ('annetsteds',),
'annetstedsfra': ('annetstedsfra',),
'annetstedshen': ('annetstedshen',),
'anno': ('anno',),
'anslagsvis': ('anslagsvis',),
'anstendigvis': ('anstendigvis',),
'anstigende': ('anstigende',),
'antakeligvis': ('antakeligvis',),
'antydningsvis': ('antydningsvis',),
'apropos': ('apropos',),
'argende': ('argende',),
'at': ('at',),
'atter': ('atter',),
'attpåtil': ('attpåtil',),
'attåt': ('attåt',),
'au': ('au',),
'avdelingsvis': ('avdelingsvis',),
'avdragsvis': ('avdragsvis',),
'avhendes': ('avhendes',),
'avhends': ('avhends',),
'avsatsvis': ('avsatsvis',),
'bakk': ('bakk',),
'baklengs': ('baklengs',),
'bare': ('bare',),
'bataljonsvis': ('bataljonsvis',),
'bekende': ('bekende',),
'belgende': ('belgende',),
'betids': ('betids',),
'bi': ('bi',),
'bidevind': ('bidevind',),
'bis': ('bis',),
'bitevis': ('bitevis',),
'bitte': ('bitte',),
'bitterlig': ('bitterlig',),
'blanko': ('blanko',),
'blidelig': ('blidelig',),
'blikk': ('blikk',),
'blikkende': ('blikkende',),
'blottende': ('blottende',),
'bom': ('bom',),
'bommende': ('bommende',),
'bona fide': ('bona fide',),
'brennfort': ('brennfort',),
'brutto': ('brutto',),
'bråtevis': ('bråtevis',),
'bums': ('bums',),
'buntevis': ('buntevis',),
'buntvis': ('buntvis',),
'bus': ('bus',),
'cantabile': ('cantabile',),
'cf': ('cf',),
'cif': ('cif',),
'cirka': ('cirka',),
'crescendo': ('crescendo',),
'da': ('da',),
'dagevis': ('dagevis',),
'dagstøtt': ('dagstøtt',),
'dakapo': ('dakapo',),
'dam': ('dam',),
'dammende': ('dammende',),
'dann': ('dann',),
'de facto': ('de facto',),
'de jure': ('de jure',),
'decrescendo': ('decrescendo',),
'delkredere': ('delkredere',),
'dels': ('dels',),
'delvis': ('delvis',),
'derav': ('derav',),
'deretter': ('deretter',),
'derfor': ('derfor',),
'derimot': ('derimot',),
'dermed': ('dermed',),
'dernest': ('dernest',),
'dess': ('dess',),
'dessuten': ('dessuten',),
'dessverre': ('dessverre',),
'desto': ('desto',),
'diminuendo': ('diminuendo',),
'dis': ('dis',),
'dog': ('dog',),
'dolce': ('dolce',),
'dorgende': ('dorgende',),
'dryppende': ('dryppende',),
'drøssevis': ('drøssevis',),
'dus': ('dus',),
'dusinvis': ('dusinvis',),
'dyende': ('dyende',),
'døgnvis': ('døgnvis',),
'dønn': ('dønn',),
'dørg': ('dørg',),
'dørgende': ('dørgende',),
'dørimellom': ('dørimellom',),
'ei': ('ei',),
'eiende': ('eiende',),
'einkom': ('einkom',),
'eitrende': ('eitrende',),
'eks': ('eks',),
'eksempelvis': ('eksempelvis',),
'ekspress': ('ekspress',),
'ekstempore': ('ekstempore',),
'eldende': ('eldende',),
'eldende': ('eldende',),
'ellers': ('ellers',),
'en': ('en',),
'en bloc': ('en bloc',),
'en detail': ('en detail',),
'en face': ('en face',),
'en gros': ('en gros',),
'en masse': ('en masse',),
'en passant': ('en passant',),
'en profil': ('en profil',),
'en suite': ('en suite',),
'enda': ('enda',),
'endatil': ('endatil',),
'ende': ('ende',),
'ender': ('ender',),
'endog': ('endog',),
'ene': ('ene',),
'engang': ('engang',),
'enkeltvis': ('enkeltvis',),
'enkom': ('enkom',),
'enn': ('enn',),
'ennå': ('ennå',),
'eo ipso': ('eo ipso',),
'ergo': ('ergo',),
'et cetera': ('et cetera',),
'etappevis': ('etappevis',),
'etterhånden': ('etterhånden',),
'etterpå': ('etterpå',),
'etterskottsvis': ('etterskottsvis',),
'etterskuddsvis': ('etterskuddsvis',),
'ex animo': ('ex animo',),
'ex auditorio': ('ex auditorio',),
'ex cathedra': ('ex cathedra',),
'ex officio': ('ex officio',),
'fas': ('fas',),
'fatt': ('fatt',),
'fatt': ('fatt',),
'feil': ('feil',),
'femti-femti': ('femti-femti',),
'fifty-fifty': ('fifty-fifty',),
'flekkevis': ('flekkevis',),
'flokkevis': ('flokkevis',),
'fluks': ('fluks',),
'fluksens': ('fluksens',),
'flunkende': ('flunkende',),
'flust': ('flust',),
'fly': ('fly',),
'fob': ('fob',),
'for': ('for',),
'for lengst': ('for lengst',),
'for resten': ('for resten',),
'for så vidt': ('for så vidt',),
'for visst': ('for visst',),
'for øvrig': ('for øvrig',),
'fordevind': ('fordevind',),
'fordum': ('fordum',),
'fore': ('fore',),
'forhakkende': ('forhakkende',),
'forholdsvis': ('forholdsvis',),
'forhåpentlig': ('forhåpentlig',),
'forhåpentligvis': ('forhåpentligvis',),
'forlengs': ('forlengs',),
'formelig': ('formelig',),
'forresten': ('forresten',),
'forsøksvis': ('forsøksvis',),
'forte': ('forte',),
'fortfarende': ('fortfarende',),
'fortissimo': ('fortissimo',),
'fortrinnsvis': ('fortrinnsvis',),
'framleis': ('framleis',),
'framlengs': ('framlengs',),
'framstupes': ('framstupes',),
'framstups': ('framstups',),
'franko': ('franko',),
'free on board': ('free on board',),
'free on rail': ('free on rail',),
'fremdeles': ('fremdeles',),
'fremlengs': ('fremlengs',),
'fremstupes': ('fremstupes',),
'fremstups': ('fremstups',),
'furioso': ('furioso',),
'fylkesvis': ('fylkesvis',),
'følgelig': ('følgelig',),
'først': ('først',),
'ganske': ('ganske',),
'gid': ('gid',),
'givetvis': ('givetvis',),
'gjerne': ('gjerne',),
'gladelig': ('gladelig',),
'glimtvis': ('glimtvis',),
'glissando': ('glissando',),
'glugg': ('glugg',),
'gorr': ('gorr',),
'gorrende': ('gorrende',),
'gradvis': ('gradvis',),
'grandioso': ('grandioso',),
'granngivelig': ('granngivelig',),
'grassat': ('grassat',),
'grave': ('grave',),
'gruppevis': ('gruppevis',),
'gudskjelov': ('gudskjelov',),
'gullende': ('gullende',),
'gørr': ('gørr',),
'gørrende': ('gørrende',),
'hakk': ('hakk',),
'hakkende': ('hakkende',),
'halvveis': ('halvveis',),
'haugevis': ('haugevis',),
'heden': ('heden',),
'heiman': ('heiman',),
'heldigvis': ('heldigvis',),
'heller': ('heller',),
'helst': ('helst',),
'henholdsvis': ('henholdsvis',),
'herre': ('herre',),
'hersens': ('hersens',),
'himlende': ('himlende',),
'hodekulls': ('hodekulls',),
'hodestupes': ('hodestupes',),
'hodestups': ('hodestups',),
'hoggende': ('hoggende',),
'honoris causa': ('honoris causa',),
'hoppende': ('hoppende',),
'hulter': ('hulter',),
'hundretusenvis': ('hundretusenvis',),
'hundrevis': ('hundrevis',),
'hurra-meg-rundt': ('hurra-meg-rundt',),
'hvi': ('hvi',),
'hvor': ('hvor',),
'hvorav': ('hvorav',),
'hvordan': ('hvordan',),
'hvorfor': ('hvorfor',),
'hånt': ('hånt',),
'høylig': ('høylig',),
'høyst': ('høyst',),
'i alle fall': ('i alle fall',),
'i stedet': ('i stedet',),
'iallfall': ('iallfall',),
'ibidem': ('ibidem',),
'id est': ('id est',),
'igjen': ('igjen',),
'ikke': ('ikke',),
'ildende': ('ildende',),
'ildende': ('ildende',),
'imens': ('imens',),
'imidlertid': ('imidlertid',),
'in absentia': ('in absentia',),
'in absurdum': ('in absurdum',),
'in blanko': ('in blanko',),
'in casu': ('in casu',),
'in contumaciam': ('in contumaciam',),
'in corpore': ('in corpore',),
'in duplo': ('in duplo',),
'in extenso': ('in extenso',),
'in flagranti': ('in flagranti',),
'in honorem': ('in honorem',),
'in medias res': ('in medias res',),
'in memoriam': ('in memoriam',),
'in mente': ('in mente',),
'in natura': ('in natura',),
'in nuce': ('in nuce',),
'in persona': ('in persona',),
'in quarto': ('in quarto',),
'in saldo': ('in saldo',),
'in salvo': ('in salvo',),
'in situ': ('in situ',),
'in solidum': ('in solidum',),
'in spe': ('in spe',),
'in triplo': ('in triplo',),
'in vitro': ('in vitro',),
'in vivo': ('in vivo',),
'ingenlunde': ('ingenlunde',),
'ingensteds': ('ingensteds',),
'inkognito': ('inkognito',),
'innenat': ('innenat',),
'innledningsvis': ('innledningsvis',),
'innleiingsvis': ('innleiingsvis',),
'isteden': ('isteden',),
'især': ('især',),
'item': ('item',),
'ja menn': ('ja menn',),
'ja så menn': ('ja så menn',),
'jammen': ('jammen',),
'jamnlig': ('jamnlig',),
'jamsides': ('jamsides',),
'jamt over': ('jamt over',),
'jamvel': ('jamvel',),
'jaså': ('jaså',),
'jevnlig': ('jevnlig',),
'jevnsides': ('jevnsides',),
'jevnt over': ('jevnt over',),
'jo menn': ('jo menn',),
'jommen': ('jommen',),
'just': ('just',),
'kanon': ('kanon',),
'kanskje': ('kanskje',),
'kav': ('kav',),
'kavende': ('kavende',),
'kilovis': ('kilovis',),
'klin': ('klin',),
'klink': ('klink',),
'klinkende': ('klinkende',),
'klokelig': ('klokelig',),
'knakende': ('knakende',),
'knapt': ('knapt',),
'knasende': ('knasende',),
'knekkende': ('knekkende',),
'knøtrende': ('knøtrende',),
'knøttende': ('knøttende',),
'kolende': ('kolende',),
'kul': ('kul',),
'kuli': ('kuli',),
'kun': ('kun',),
'kvartalsvis': ('kvartalsvis',),
'kvekk': ('kvekk',),
'kølende': ('kølende',),
'lagerfritt': ('lagerfritt',),
'lagom': ('lagom',),
'lagvis': ('lagvis',),
'larghetto': ('larghetto',),
'largo': ('largo',),
'lassevis': ('lassevis',),
'legato': ('legato',),
'leilighetsvis': ('leilighetsvis',),
'lell': ('lell',),
'lenger': ('lenger',),
'liddelig': ('liddelig',),
'like': ('like',),
'likeledes': ('likeledes',),
'likeså': ('likeså',),
'likevel': ('likevel',),
'likså': ('likså',),
'lissom': ('lissom',),
'litervis': ('litervis',),
'livende': ('livende',),
'lovformelig': ('lovformelig',),
'lovlig': ('lovlig',),
'lukt': ('lukt',),
'lut': ('lut',),
'luta': ('luta',),
'lutende': ('lutende',),
'lykkeligvis': ('lykkeligvis',),
'lynfort': ('lynfort',),
'lys': ('lys',),
'maestoso': ('maestoso',),
'mala fide': ('mala fide',),
'malapropos': ('malapropos',),
'massevis': ('massevis',),
'med rette': ('med rette',),
'medio': ('medio',),
'medium': ('medium',),
'meget': ('meget',),
'mengdevis': ('mengdevis',),
'metervis': ('metervis',),
'mezzoforte': ('mezzoforte',),
'midsommers': ('midsommers',),
'midsommers': ('midsommers',),
'midt': ('midt',),
'midtsommers': ('midtsommers',),
'midtsommers': ('midtsommers',),
'midtvinters': ('midtvinters',),
'midvinters': ('midvinters',),
'milevis': ('milevis',),
'millionvis': ('millionvis',),
'min sann': ('min sann',),
'min sant': ('min sant',),
'min santen': ('min santen',),
'minus': ('minus',),
'mo': ('mo',),
'molto': ('molto',),
'motsols': ('motsols',),
'motstrøms': ('motstrøms',),
'mukk': ('mukk',),
'mukkende': ('mukkende',),
'muligens': ('muligens',),
'muligvis': ('muligvis',),
'murende': ('murende',),
'musende': ('musende',),
'mutters': ('mutters',),
'månedsvis': ('månedsvis',),
'naggende': ('naggende',),
'naturligvis': ('naturligvis',),
'nauende': ('nauende',),
'navnlig': ('navnlig',),
'neigu': ('neigu',),
'neimen': ('neimen',),
'nemlig': ('nemlig',),
'neppe': ('neppe',),
'nesegrus': ('nesegrus',),
'nest': ('nest',),
'nesten': ('nesten',),
'netto': ('netto',),
'nettopp': ('nettopp',),
'noenlunde': ('noenlunde',),
'noensinne': ('noensinne',),
'noensteds': ('noensteds',),
'nok': ('nok',),
'nok': ('nok',),
'noksom': ('noksom',),
'nokså': ('nokså',),
'non stop': ('non stop',),
'nonstop': ('nonstop',),
'notabene': ('notabene',),
'nu': ('nu',),
'nylig': ('nylig',),
'nyss': ('nyss',),
'nå': ('nå',),
'når': ('når',),
'nåvel': ('nåvel',),
'nære': ('nære',),
'nærere': ('nærere',),
'nærest': ('nærest',),
'nærmere': ('nærmere',),
'nærmest': ('nærmest',),
'nødvendigvis': ('nødvendigvis',),
'offside': ('offside',),
'også': ('også',),
'om att': ('om att',),
'om igjen': ('om igjen',),
'omme': ('omme',),
'omsider': ('omsider',),
'omsonst': ('omsonst',),
'omtrent': ('omtrent',),
'onnimellom': ('onnimellom',),
'opp att': ('opp att',),
'opp ned': ('opp ned',),
'oppad': ('oppad',),
'oppstrøms': ('oppstrøms',),
'oven': ('oven',),
'overalt': ('overalt',),
'overens': ('overens',),
'overhodet': ('overhodet',),
'overlag': ('overlag',),
'overmorgen': ('overmorgen',),
'overmåte': ('overmåte',),
'overvettes': ('overvettes',),
'pakkende': ('pakkende',),
'pal': ('pal',),
'par avion': ('par avion',),
'par excellence': ('par excellence',),
'parlando': ('parlando',),
'pars pro toto': ('pars pro toto',),
'partout': ('partout',),
'parvis': ('parvis',),
'per capita': ('per capita',),
'peu à peu': ('peu à peu',),
'peu om peu': ('peu om peu',),
'pianissimo': ('pianissimo',),
'piano': ('piano',),
'pinende': ('pinende',),
'pinnende': ('pinnende',),
'pist': ('pist',),
'pizzicato': ('pizzicato',),
'pladask': ('pladask',),
'plent': ('plent',),
'plenty': ('plenty',),
'pluss': ('pluss',),
'porsjonsvis': ('porsjonsvis',),
'portamento': ('portamento',),
'portato': ('portato',),
'post festum': ('post festum',),
'post meridiem': ('post meridiem',),
'post mortem': ('post mortem',),
'prestissimo': ('prestissimo',),
'presto': ('presto',),
'prima vista': ('prima vista',),
'primo': ('primo',),
'pro anno': ('pro anno',),
'pro persona': ('pro persona',),
'pro tempore': ('pro tempore',),
'proforma': ('proforma',),
'prompt': ('prompt',),
'prompte': ('prompte',),
'proppende': ('proppende',),
'prosentvis': ('prosentvis',),
'pukka': ('pukka',),
'puljevis': ('puljevis',),
'punktvis': ('punktvis',),
'pyton': ('pyton',),
'pø om pø': ('pø om pø',),
'quantum satis': ('quantum satis',),
'rammende': ('rammende',),
'rangsøles': ('rangsøles',),
'rasende': ('rasende',),
'ratevis': ('ratevis',),
'ratt': ('ratt',),
'rav': ('rav',),
'ravende': ('ravende',),
'reint': ('reint',),
'rent': ('rent',),
'respektive': ('respektive',),
'rettsøles': ('rettsøles',),
'reverenter': ('reverenter',),
'riktig nok': ('riktig nok',),
'riktignok': ('riktignok',),
'rimeligvis': ('rimeligvis',),
'ringside': ('ringside',),
'rispende': ('rispende',),
'ritardando': ('ritardando',),
'riv': ('riv',),
'rubato': ('rubato',),
'ruskende': ('ruskende',),
'rykkevis': ('rykkevis',),
'saktelig': ('saktelig',),
'saktens': ('saktens',),
'sammen': ('sammen',),
'samstundes': ('samstundes',),
'samt': ('samt',),
'sann': ('sann',),
'sannelig': ('sannelig',),
'sannsynligvis': ('sannsynligvis',),
'sans phrase': ('sans phrase',),
'scilicet': ('scilicet',),
'seinhøstes': ('seinhøstes',),
'senhøstes': ('senhøstes',),
'sia': ('sia',),
'sic': ('sic',),
'sidelengs': ('sidelengs',),
'siden': ('siden',),
'sideveges': ('sideveges',),
'sidevegs': ('sidevegs',),
'sideveis': ('sideveis',),
'sikkerlig': ('sikkerlig',),
'silde': ('silde',),
'simpelthen': ('simpelthen',),
'sine anno': ('sine anno',),
'sjelden': ('sjelden',),
'sjøleies': ('sjøleies',),
'sjøleis': ('sjøleis',),
'sjøverts': ('sjøverts',),
'skeis': ('skeis',),
'skiftevis': ('skiftevis',),
'skita': ('skita',),
'skjøns': ('skjøns',),
'skogleies': ('skogleies',),
'skokkevis': ('skokkevis',),
'skrevs': ('skrevs',),
'skrittvis': ('skrittvis',),
'skrås': ('skrås',),
'skyllende': ('skyllende',),
'skåldende': ('skåldende',),
'slettes': ('slettes',),
'sluttelig': ('sluttelig',),
'smekk': ('smekk',),
'smellende': ('smellende',),
'småningom': ('småningom',),
'sneisevis': ('sneisevis',),
'snesevis': ('snesevis',),
'snuft': ('snuft',),
'snupt': ('snupt',),
'snyt': ('snyt',),
'snyta': ('snyta',),
'snyte': ('snyte',),
'solo': ('solo',),
'sommerstid': ('sommerstid',),
'spenna': ('spenna',),
'spent': ('spent',),
'spika': ('spika',),
'spikende': ('spikende',),
'spildrende': ('spildrende',),
'spill': ('spill',),
'splinter': ('splinter',),
'splitter': ('splitter',),
'sporenstreks': ('sporenstreks',),
'sprangvis': ('sprangvis',),
'sprell': ('sprell',),
'sprut': ('sprut',),
'sprutende': ('sprutende',),
'sprøyte': ('sprøyte',),
'stakkato': ('stakkato',),
'stapp': ('stapp',),
'stappa': ('stappa',),
'stappende': ('stappende',),
'staurende': ('staurende',),
'stedvis': ('stedvis',),
'steika': ('steika',),
'stein': ('stein',),
'steinsens': ('steinsens',),
'stokk': ('stokk',),
'stokkende': ('stokkende',),
'straks': ('straks',),
'stringendo': ('stringendo',),
'stummende': ('stummende',),
'stundimellom': ('stundimellom',),
'stundom': ('stundom',),
'stundomtil': ('stundomtil',),
'stupende': ('stupende',),
'styggelig': ('styggelig',),
'styggende': ('styggende',),
'stykkevis': ('stykkevis',),
'støtt': ('støtt',),
'støtvis': ('støtvis',),
'støytvis': ('støytvis',),
'sub rosa': ('sub rosa',),
'summa summarum': ('summa summarum',),
'surr': ('surr',),
'svinaktig': ('svinaktig',),
'sydøst': ('sydøst',),
'synderlig': ('synderlig',),
'så': ('så',),
'så pass': ('så pass',),
'sågar': ('sågar',),
'således': ('således',),
'såleis': ('såleis',),
'såpass': ('såpass',),
'såre': ('såre',),
'særdeles': ('særdeles',),
'særs': ('særs',),
'søkk': ('søkk',),
'søkkende': ('søkkende',),
'sønder': ('sønder',),
'takimellom': ('takimellom',),
'takomtil': ('takomtil',),
'temmelig': ('temmelig',),
'ti': ('ti',),
'tidligdags': ('tidligdags',),
'tidsnok': ('tidsnok',),
'tidvis': ('tidvis',),
'tilfeldigvis': ('tilfeldigvis',),
'tilmed': ('tilmed',),
'tilnærmelsesvis': ('tilnærmelsesvis',),
'timevis': ('timevis',),
'tjokkende': ('tjokkende',),
'tomreipes': ('tomreipes',),
'tott': ('tott',),
'trill': ('trill',),
'trillende': ('trillende',),
'trinnvis': ('trinnvis',),
'troppevis': ('troppevis',),
'troppo': ('troppo',),
'troppsvis': ('troppsvis',),
'trutt': ('trutt',),
'turevis': ('turevis',),
'turvis': ('turvis',),
'tusenfold': ('tusenfold',),
'tusenvis': ('tusenvis',),
'tvers': ('tvers',),
'tvert': ('tvert',),
'tydeligvis': ('tydeligvis',),
'tynnevis': ('tynnevis',),
'tynnevis': ('tynnevis',),
'tålig': ('tålig',),
'tønnevis': ('tønnevis',),
'tønnevis': ('tønnevis',),
'ufravendt': ('ufravendt',),
'ugjerne': ('ugjerne',),
'uheldigvis': ('uheldigvis',),
'ukevis': ('ukevis',),
'ukevis': ('ukevis',),
'ulykkeligvis': ('ulykkeligvis',),
'uløyves': ('uløyves',),
'underhånden': ('underhånden',),
'undertiden': ('undertiden',),
'unntakelsesvis': ('unntakelsesvis',),
'unntaksvis': ('unntaksvis',),
'ustyggelig': ('ustyggelig',),
'utaboks': ('utaboks',),
'utbygdes': ('utbygdes',),
'utdragsvis': ('utdragsvis',),
'utelukkende': ('utelukkende',),
'utenat': ('utenat',),
'utenboks': ('utenboks',),
'uvegerlig': ('uvegerlig',),
'uviselig': ('uviselig',),
'uvislig': ('uvislig',),
'va banque': ('va banque',),
'vanligvis': ('vanligvis',),
'vann': ('vann',),
'vekevis': ('vekevis',),
'vekevis': ('vekevis',),
'vekselvis': ('vekselvis',),
'vel': ('vel',),
'vibrato': ('vibrato',),
'vice versa': ('vice versa',),
'vide': ('vide',),
'viden': ('viden',),
'vinterstid': ('vinterstid',),
'viselig': ('viselig',),
'visselig': ('visselig',),
'visst': ('visst',),
'visst nok': ('visst nok',),
'visstnok': ('visstnok',),
'vivace': ('vivace',),
'vonlig': ('vonlig',),
'vonom': ('vonom',),
'vonoms': ('vonoms',),
'vrangsøles': ('vrangsøles',),
'ytterlig': ('ytterlig',),
'åkkesom': ('åkkesom',),
'årevis': ('årevis',),
'årlig års': ('årlig års',),
'åssen': ('åssen',),
'ørende': ('ørende',),
'øyensynlig': ('øyensynlig',),
'antageligvis': ('antageligvis',),
'coolly': ('coolly',),
'kor': ('kor',),
'korfor': ('korfor',),
'kor': ('kor',),
'korfor': ('korfor',),
'medels': ('medels',),
'nasegrus': ('nasegrus',),
'overimorgen': ('overimorgen',),
'unntagelsesvis': ('unntagelsesvis',),
'åffer': ('åffer',),
'åffer': ('åffer',),
'sist': ('sist',),
'seinhaustes': ('seinhaustes',),
'stetse': ('stetse',),
'stikk': ('stikk',),
'storlig': ('storlig',),
'A': ('A',),
'for': ('for',),
'benveges': ('benveges',),
'bunkevis': ('bunkevis',),
'selv': ('selv',),
'sjøl': ('sjøl',),
'skauleies': ('skauleies',),
'da capo': ('da capo',),
'beint frem': ('beint frem',),
'beintfrem': ('beintfrem',),
'beinveges': ('beinveges',),
'beinvegs': ('beinvegs',),
'beinveis': ('beinveis',),
'benvegs': ('benvegs',),
'benveis': ('benveis',),
'en garde': ('en garde',),
'framåt': ('framåt',),
'krittende': ('krittende',),
'kvivitt': ('kvivitt',),
'maksis': ('maksis',),
'mangesteds': ('mangesteds',),
'møkka': ('møkka',),
'pill': ('pill',),
'sellende': ('sellende',),
'sirka': ('sirka',),
'subito': ('subito',),
'til sammen': ('til sammen',),
'tomrepes': ('tomrepes',),
'medurs': ('medurs',),
'moturs': ('moturs',)
}



# coding: utf8
from __future__ import unicode_literals

from ...symbols import ORTH


_exc = {}


# Source: https://en.wiktionary.org/wiki/Category:Romanian_abbreviations
for orth in [
    "1-a", "2-a", "3-a", "4-a", "5-a", "6-a", "7-a", "8-a", "9-a", "10-a", "11-a", "12-a",
    "1-ul", "2-lea", "3-lea", "4-lea", "5-lea", "6-lea", "7-lea", "8-lea", "9-lea", "10-lea", "11-lea", "12-lea",
    "d-voastră", "dvs.", "ing.", "dr.", "Rom.", "str.", "nr.", "etc.", "d.p.d.v.", "dpdv", "șamd.", "ș.a.m.d."]:
    _exc[orth] = [{ORTH: orth}]


TOKENIZER_EXCEPTIONS = _exc



# coding: utf8
from __future__ import unicode_literals


ADVERBS = set("""
 abandonnément abjectement abominablement abondamment aboralement abouliquement
 abruptement abrégément abréviativement absconsement absconsément absolument
 abstraitement abstrusément absurdement abusivement académiquement
 accelerando acceptablement accessoirement accidentellement accortement
 acidement acoustiquement acrimonieusement acrobatiquement actiniquement
 actuellement adagio additionnellement additivement adiabatiquement
 adjectivement administrativement admirablement admirativement adorablement
 adultérieurement adverbialement adversativement adéquatement affablement
 affectionnément affectivement affectueusement affinement affirmativement
 agilement agitato agnostiquement agogiquement agressivement agrestement
 agrologiquement agronomiquement agréablement aguicheusement aidant aigrement
 ailleurs aimablement ainsi aisément alchimiquement alcooliquement alentour
 algorithmiquement algébriquement alias alimentairement allegretto allegro
 allopathiquement allusivement allègrement allégoriquement allégrement allégro
 alphabétiquement alternativement altimétriquement altièrement altruistement
 amabile ambigument ambitieusement amiablement amicalement amiteusement
 amoroso amoureusement amphibologiquement amphigouriquement amplement
 amusément amènement amèrement anachroniquement anagogiquement
 analogiquement analoguement analytiquement anaphoriquement anarchiquement
 ancestralement anciennement andante andantino anecdotiquement angulairement
 angéliquement anharmoniquement animalement animato annuellement anodinement
 anormalement anthropocentriquement anthropologiquement anthropomorphiquement
 anticipativement anticonstitutionnellement antidémocratiquement
 antinomiquement antipathiquement antipatriotiquement antiquement
 antisocialement antisportivement antisymétriquement antithétiquement
 antiétatiquement antécédemment antérieurement anxieusement apathiquement
 apicalement apocalyptiquement apodictiquement apologétiquement apostoliquement
 appassionato approbativement approchant approximativement appréciablement
 après-demain aquatiquement arbitrairement arbitralement archaïquement
 architecturalement archéologiquement ardemment argotiquement aridement
 arithmétiquement aromatiquement arrière arrogamment articulairement
 artificiellement artificieusement artisanalement artistement artistiquement
 aseptiquement asiatiquement assai assertivement assertoriquement assez
 associativement assurément astrologiquement astrométriquement astronomiquement
 astucieusement asymptotiquement asymétriquement ataviquement ataxiquement
 atomiquement atrabilairement atrocement attenant attentionnément attentivement
 attractivement atypiquement aucunement audacieusement audiblement
 auditivement auguralement augustement aujourd'hui auparavant auprès
 aussi aussitôt austèrement autant autarciquement authentiquement
 autographiquement automatiquement autonomement autoritairement autrefois
 auxiliairement avant avant-hier avantageusement avarement avaricieusement
 aventurément aveuglément avidement avunculairement axialement axiologiquement
 aériennement aérodynamiquement aérostatiquement babéliquement bachiquement
 badaudement badinement balistiquement balourdement balsamiquement banalement
 barbarement barométriquement baroquement bas bassement batailleusement
 baveusement beau beaucoup bellement belliqueusement ben bene benoîtement
 bestialement bibliographiquement bibliquement bien bienheureusement bientôt
 bigotement bigrement bihebdomadairement bijectivement bijournellement
 bileusement bilieusement bilinéairement bimensuellement bimestriellement
 bioacoustiquement biochimiquement bioclimatiquement biodynamiquement
 biogénétiquement biologiquement biomédicalement bioniquement biophysiquement
 bioélectroniquement bioénergétiquement bipolairement biquotidiennement bis
 biunivoquement bizarrement bizarroïdement blafardement blagueusement
 blondement blâmablement bon bonassement bonnement bordéliquement botaniquement
 boueusement bouffonnement bougonnement bougrement boulimiquement
 bravachement bravement bredouilleusement bref brillamment brièvement
 brumeusement brusquement brut brutalement bruyamment bucoliquement
 bureaucratiquement burlesquement byzantinement béatement bégueulement
 bénéfiquement bénévolement béotiennement bésef bézef bêtement cabalistiquement
 cabotinement cachottièrement cacophoniquement caf cafardeusement
 cajoleusement calamiteusement calligraphiquement calmement calmos
 calorimétriquement caloriquement canaillement cancérologiquement candidement
 cantabile capablement capillairement capitalement capitulairement
 captieusement caractériellement caractérologiquement cardiographiquement
 caricaturalement carrément cartographiquement cartésiennement casanièrement
 casuellement catalytiquement catastrophiquement catholiquement
 catégoriquement causalement causativement caustiquement cauteleusement
 caverneusement cellulairement censitairement censément centièmement
 cependant certainement certes cf chafouinement chagrinement chaleureusement
 chaotiquement charismatiquement charitablement charnellement chastement
 chattement chaud chaudement chauvinement chenuement cher chevaleresquement
 chichement chichiteusement chimiquement chimériquement chinoisement
 chiquement chirographairement chirographiquement chirurgicalement chiément
 chouettement chromatiquement chroniquement chronologiquement
 chrétiennement chèrement chétivement ci cinquantièmement cinquièmement
 cinématographiquement cinétiquement circonspectement circonstanciellement
 citadinement civilement civiquement clairement clandestinement classiquement
 climatologiquement cliniquement cléricalement cocassement cochonnement
 coextensivement collatéralement collectivement collusoirement collégialement
 coléreusement colériquement combien combinatoirement comiquement comme
 comment commercialement comminatoirement commodément communalement
 communément comparablement comparativement compatiblement compendieusement
 compensatoirement complaisamment complexement complètement complémentairement
 compréhensivement comptablement comptant compulsivement conardement
 conceptuellement concernant concevablement concisément concomitamment
 concurremment concussionnairement condamnablement conditionnellement confer
 confidemment confidentiellement conflictuellement conformationnellement
 confortablement confraternellement confusément confédéralement congrument
 congénitalement coniquement conjecturalement conjointement conjonctivement
 conjugalement connardement connement connotativement consciemment
 consensuellement conservatoirement considérablement considérément
 constamment constitutionnellement constitutivement consubstantiellement
 consécutivement conséquemment contagieusement contemplativement
 contestablement contextuellement continuellement continûment contractuellement
 contrairement contrapuntiquement contrastivement contre contributoirement
 convenablement conventionnellement conventuellement convivialement
 coopérativement copieusement coquettement coquinement cordialement coriacement
 coronairement corporativement corporellement corpusculairement correct
 correctionnellement corrosivement corrélativement cosmiquement
 cosmographiquement cosmologiquement cossardement cotonneusement couardement
 courageusement couramment court courtement courtoisement coutumièrement
 craintivement crapuleusement crescendo criardement criminellement
 critiquablement critiquement croyez-en crucialement cruellement
 crânement crédiblement crédulement crépusculairement crétinement crûment
 cuistrement culinairement cultuellement culturellement cumulativement
 curativement curieusement cursivement curvilignement cybernétiquement
 cylindriquement cyniquement cynégétiquement cytogénétiquement cytologiquement
 célestement célibatairement cérébralement cérémoniellement cérémonieusement
 d'abondance d'abord d'ailleurs d'après d'arrache-pied d'avance d'emblée d'ici
 d'office d'urgence d'évidence dactylographiquement damnablement dangereusement
 debout decimo decrescendo dedans dehors demain densément depuis derechef
 dernièrement derrière descriptivement despotiquement deusio deuxièmement
 devant dextrement dextrorse dextrorsum diablement diaboliquement
 diacoustiquement diagonalement dialectalement dialectiquement
 dialogiquement diamétralement diantrement diatoniquement dichotomiquement
 didactiquement difficilement difficultueusement diffusément différemment
 digitalement dignement dilatoirement diligemment dimanche dimensionnellement
 dinguement diplomatiquement directement directo disciplinairement
 discontinûment discourtoisement discriminatoirement discrètement
 discursivement disertement disgracieusement disjonctivement disons-le
 dispendieusement disproportionnellement disproportionnément dissemblablement
 dissuasivement dissymétriquement distinctement distinctivement distraitement
 distributivement dithyrambiquement dito diurnement diversement divinement
 dixièmement diététiquement docilement docimologiquement doctement
 doctrinairement doctrinalement documentairement dodécaphoniquement
 dogmatiquement dolce dolcissimo dolemment dolentement dolosivement
 dommageablement donc dont doriquement dorsalement dorénavant doublement
 doucereusement doucettement douceâtrement douillettement douloureusement
 doux douzièmement draconiennement dramatiquement drastiquement
 droit droitement drolatiquement dru drument drôlement dubitativement dur
 durement dynamiquement dynamogéniquement dysharmoniquement débilement
 décadairement décemment décidément décimalement décisivement déclamatoirement
 dédaigneusement déductivement défavorablement défectueusement défensivement
 définitivement dégoûtamment dégressivement dégueulassement déictiquement déjà
 délibérément délicatement délicieusement déloyalement délétèrement
 démentiellement démesurément démocratiquement démographiquement démoniaquement
 démonstrativement démotiquement déontologiquement départementalement
 déplaisamment déplorablement dépressivement dépréciativement déraisonnablement
 dérivationnellement dérogativement dérogatoirement désagréablement
 désastreusement désavantageusement désespéramment désespérément déshonnêtement
 désobligeamment désolamment désordonnément désormais déterminément
 dévotement dévotieusement dûment ecclésiastiquement ecclésiologiquement
 efficacement effrayamment effrontément effroyablement effrénément
 elliptiquement emblématiquement embryologiquement embryonnairement
 emphatiquement empiriquement encor encore encyclopédiquement
 endémiquement enfantinement enfin enjôleusement ennuyeusement ensemble
 ensuite enthousiastement entièrement entomologiquement enviablement
 environ ergonomiquement erratiquement erronément eschatologiquement
 espressivo essentiellement esthétiquement estimablement etc ethniquement
 ethnolinguistiquement ethnologiquement eucharistiquement euphoniquement
 euphémiquement euristiquement européennement eurythmiquement euréka exactement
 exaspérément excellemment excentriquement exceptionnellement excepté
 exclamativement exclusivement excédentairement exemplairement exhaustivement
 existentiellement exorbitamment exotiquement expansivement expertement
 explicativement explicitement explosivement explétivement exponentiellement
 expressément exprès expéditivement expérimentalement exquisément extatiquement
 extensionnellement extensivement extra-muros extrajudiciairement
 extravagamment extrinsèquement extrêmement extérieurement exécrablement
 exégétiquement fabuleusement facheusement facile facilement facticement
 factitivement factuellement facultativement facétieusement fadassement
 faiblardement faiblement fallacieusement falotement fameusement familialement
 faméliquement fanatiquement fanfaronnement fangeusement fantaisistement
 fantasmatiquement fantasquement fantastiquement fantomatiquement
 faramineusement faraudement farouchement fascistement fashionablement
 fastueusement fatalement fatalistement fatidiquement faussement fautivement
 favorablement ferme fermement ferroviairement fertilement fervemment
 fichtrement fichument fichûment fictivement fiduciairement fidèlement
 figurativement figurément filandreusement filialement filmiquement fin
 financièrement finaudement finement finiment fiscalement fissa fixement
 fiévreusement flagorneusement flasquement flatteusement flegmatiquement
 flexionnellement flexueusement flou fluidement flâneusement flémardement
 foireusement folkloriquement follement folâtrement foncièrement
 fondamentalement forcément forestièrement forfaitairement formellement
 fort forte fortement fortissimo fortuitement fougueusement fourbement
 foutument foutûment fragilement fragmentairement frais franc franchement
 fraternellement frauduleusement fraîchement frigidement frigo frileusement
 frisquet frivolement froidement frontalement froussardement fructueusement
 frustement frénétiquement fréquemment frêlement fugacement fugitivement
 fumeusement funestement funèbrement funérairement furibardement furibondement
 furioso furtivement futilement futurement fâcheusement fébrilement fécondement
 félinement félonnement fémininement féodalement férocement fétidement
 gaffeusement gaiement gaillardement galamment gallicanement galvaniquement
 gammathérapiquement ganglionnairement gargantualement gastronomiquement
 gauloisement gaîment geignardement gentement gentiment gestuellement
 giratoirement glacialement glaciologiquement glaireusement glandulairement
 globalement glorieusement gloutonnement gnostiquement gnoséologiquement
 goguenardement goinfrement goniométriquement gothiquement gouailleusement
 goulûment gourdement gourmandement goutteusement gouvernementalement
 gracilement gracioso graduellement grammaticalement grand grandement
 graphiquement graphologiquement gras grassement gratis gratuitement grave
 gravement grazioso grincheusement grivoisement grièvement grossement
 grotesquement grégairement guillerettement gutturalement guère guères
 gyroscopiquement gâteusement gélatineusement génialement génitalement
 généralement généreusement génériquement génétiquement géodynamiquement
 géographiquement géologiquement géométralement géométriquement géophysiquement
 habilement habituellement hagardement hagiographiquement haineusement
 hargneusement harmonieusement harmoniquement hasardeusement haut hautainement
 haïssablement hebdomadairement heptagonalement herméneutiquement
 heureusement heuristiquement hexagonalement hexaédriquement hideusement hier
 hippiatriquement hippiquement hippologiquement histologiquement historiquement
 hiératiquement hiéroglyphiquement homocentriquement homographiquement
 homologiquement homothétiquement homéopathiquement homériquement honnêtement
 honorifiquement honteusement horizontalement hormis hormonalement horriblement
 hospitalièrement hostilement houleusement huileusement huitièmement
 humanitairement humblement humidement humoristiquement humoureusement
 hydrauliquement hydrodynamiquement hydrographiquement hydrologiquement
 hydropneumatiquement hydrostatiquement hydrothérapiquement hygiéniquement
 hypercorrectement hypnotiquement hypocondriaquement hypocoristiquement
 hypodermiquement hypostatiquement hypothécairement hypothétiquement
 hâtivement hébraïquement héliaquement hélicoïdalement héliographiquement
 hémiédriquement hémodynamiquement hémostatiquement héraldiquement héroïquement
 hérétiquement hétéroclitement hétérodoxement hétérogènement ibidem
 ici ici-bas iconiquement iconographiquement id idem identiquement
 idiosyncrasiquement idiosyncratiquement idiotement idoinement idolatriquement
 idylliquement idéalement idéalistement idéellement idéographiquement
 ignarement ignoblement ignominieusement ignoramment illicitement illico
 illogiquement illusoirement illustrement illégalement illégitimement
 imaginativement imbattablement imbécilement immaculément immanquablement
 immensément imminemment immobilement immodestement immodérément immondement
 immortellement immuablement immunitairement immunologiquement immédiatement
 immémorialement impairement impalpablement imparablement impardonnablement
 impartialement impassiblement impatiemment impavidement impayablement
 impensablement imperceptiblement impersonnellement impertinemment
 impitoyablement implacablement implicitement impoliment impolitiquement
 importunément impossiblement imprescriptiblement impressivement improbablement
 impromptu improprement imprudemment imprécisément imprévisiblement impudemment
 impulsivement impunément impurement impénétrablement impérativement
 impérieusement impérissablement impétueusement inacceptablement
 inactivement inadmissiblement inadéquatement inaliénablement inaltérablement
 inamoviblement inappréciablement inassouvissablement inattaquablement
 inaudiblement inauguralement inauthentiquement inavouablement incalculablement
 incertainement incessamment incestueusement incidemment incisivement
 inciviquement inclusivement incoerciblement incognito incommensurablement
 incommutablement incomparablement incomplètement incompréhensiblement
 inconcevablement inconciliablement inconditionnellement inconfortablement
 inconsciemment inconsidérément inconsolablement inconstamment
 inconséquemment incontestablement incontinent incontournablement
 inconvenablement incorporellement incorrectement incorrigiblement
 increvablement incroyablement incrédulement incurablement indescriptiblement
 indicativement indiciairement indiciblement indifféremment indigemment
 indignement indirectement indiscernablement indiscontinûment indiscrètement
 indispensablement indissociablement indissolublement indistinctement
 indivisiblement indivisément indocilement indolemment indomptablement
 inductivement indulgemment industriellement industrieusement indécelablement
 indéchiffrablement indécrottablement indéfectiblement indéfendablement
 indéfinissablement indélicatement indélébilement indémontablement
 indépassablement indépendamment indéracinablement indésirablement
 indéterminément indévotement indûment ineffablement ineffaçablement
 ineptement inertement inespérément inesthétiquement inestimablement
 inexcusablement inexorablement inexpertement inexpiablement inexplicablement
 inexprimablement inexpugnablement inextinguiblement inextirpablement
 infailliblement infantilement infatigablement infectement infernalement
 infimement infiniment infinitésimalement inflexiblement informatiquement
 infra infructueusement infâmement inférieurement inglorieusement ingratement
 ingénieusement ingénument inhabilement inhabituellement inharmonieusement
 inhospitalièrement inhumainement inhéremment inimaginablement inimitablement
 inintelligiblement inintentionnellement iniquement initialement
 injurieusement injustement injustifiablement inlassablement innocemment
 inoffensivement inopinément inopportunément inoubliablement inoxydablement
 inquisitorialement inquiètement insaisissablement insalubrement insanement
 insciemment insensiblement insensément insidieusement insignement
 insipidement insolemment insolitement insolublement insondablement
 insoucieusement insoupçonnablement insoutenablement instablement instamment
 instinctivement institutionnellement instructivement instrumentalement
 insulairement insupportablement insurmontablement insurpassablement
 inséparablement intangiblement intarissablement intellectuellement
 intelligiblement intempestivement intemporellement intenablement
 intensivement intensément intentionnellement intercalairement
 interlinéairement interlopement interminablement intermusculairement
 interplanétairement interprofessionnellement interprétativement
 intersyndicalement intervocaliquement intimement intolérablement
 intraitablement intramusculairement intransitivement intraveineusement
 introspectivement intrépidement intuitivement intègrement intégralement
 intérimairement inutilement invalidement invariablement inventivement
 invinciblement inviolablement invisiblement involontairement
 invulnérablement inébranlablement inégalablement inégalement inégalitairement
 inélégamment inénarrablement inépuisablement inéquitablement inévitablement
 ironiquement irraisonnablement irrationnellement irrattrapablement
 irrespectueusement irrespirablement irresponsablement irréconciliablement
 irrécusablement irréductiblement irréellement irréfragablement irréfutablement
 irréligieusement irrémissiblement irrémédiablement irréparablement
 irréprochablement irrépréhensiblement irrésistiblement irrésolument
 irrévocablement irrévéremment irrévérencieusement isolément isothermiquement
 isoédriquement item itou itérativement jacobinement jadis jalousement jamais
 jaune jeudi jeunement jobardement jointivement joliment journalistiquement
 jovialement joyeusement judaïquement judiciairement judicieusement
 juste justement justifiablement juvénilement juxtalinéairement jésuitement
 kaléidoscopiquement kilométriquement l'année l'après-midi l'avant-veille
 labialement laborieusement labyrinthiquement laconiquement lactiquement
 ladrement laidement laiteusement lamentablement langagièrement langoureusement
 languissamment lapidairement large largement larghetto largo lascivement
 latinement latéralement laxistement laïquement legato lentement lento lerch
 lestement lexicalement lexicographiquement lexicologiquement libertinement
 librement libéralement licencieusement licitement ligamentairement
 limitativement limpidement linguistiquement linéairement linéalement
 lisiblement lithographiquement lithologiquement litigieusement littérairement
 liturgiquement lividement livresquement localement logarithmiquement
 logistiquement logographiquement loin lointainement loisiblement long
 longitudinalement longtemps longuement loquacement lors louablement
 louchement loufoquement lourd lourdaudement lourdement loyalement lubriquement
 lucrativement ludiquement lugubrement lumineusement lunairement lunatiquement
 lustralement luxueusement luxurieusement lymphatiquement lyriquement là là-bas
 là-dessous là-dessus là-haut lâchement légalement légendairement léger
 légitimement légèrement léthargiquement macabrement macache macaroniquement
 machinalement macrobiotiquement macroscopiquement maestoso magiquement
 magnanimement magnifiquement magnétiquement magnétohydrodynamiquement
 maigrement maintenant majestueusement majoritairement mal maladivement
 malaisément malcommodément malencontreusement malgracieusement malgré
 malheureusement malhonnêtement malicieusement malignement malproprement
 malveillamment maléfiquement maniaquement manifestement manuellement mardi
 maritalement maritimement marmiteusement marotiquement marre martialement
 masochistement massivement maternellement mathématiquement matin matinalement
 matriarcalement matrilinéairement matrimonialement maturément matérialistement
 maupiteusement mauresquement maussadement mauvais mauvaisement maxi
 meilleur mensongèrement mensuellement mentalement menteusement menu
 mercredi merdeusement merveilleusement mesquinement mesurément mezzo
 micrographiquement micrométriquement microphysiquement microscopiquement
 miette mieux mignardement mignonnement militairement millimétriquement
 minablement mincement minimement ministériellement minoritairement
 minutieusement minéralogiquement miraculeusement mirifiquement mirobolamment
 misanthropiquement misogynement misérablement miséreusement
 miteusement mièvrement mnémoniquement mnémotechniquement mobilièrement
 modalement moderato modernement modestement modiquement modulairement
 moelleusement moindrement moins mollassement mollement mollo molto
 momentanément monacalement monarchiquement monastiquement mondainement
 monocordement monographiquement monolithiquement monophoniquement monotonement
 monumentalement monétairement moqueusement moralement moralistement
 mordicus morganatiquement mornement morosement morphologiquement mortellement
 morveusement moult moutonnièrement moyennant moyennement moyenâgeusement
 multidisciplinairement multilatéralement multinationalement multiplement
 multipolairement municipalement musculairement musculeusement musicalement
 mutuellement mystiquement mystérieusement mythiquement mythologiquement
 mécanographiquement méchamment médialement médiatement médiatiquement
 médicinalement médiocrement méditativement mélancoliquement mélodieusement
 mélodramatiquement mémorablement méphistophéliquement méprisablement
 méritoirement métaboliquement métalinguistiquement métalliquement
 métallurgiquement métalogiquement métamathématiquement métaphoriquement
 méthodiquement méthodologiquement méticuleusement métonymiquement métriquement
 météorologiquement même mêmement mûrement n'étant naguère narcissiquement
 narrativement nasalement nasillardement natalement nationalement nativement
 naturellement naïvement ne nenni nerveusement net nettement
 neurolinguistiquement neurologiquement neurophysiologiquement
 neutrement neuvièmement niaisement nib nigaudement noblement nocivement
 noirement nomadement nombreusement nominalement nominativement nommément non
 nonobstant noologiquement normalement normativement nostalgiquement
 notamment notarialement notoirement nouménalement nouvellement noétiquement
 nucléairement nuisiblement nuitamment nullement numismatiquement numériquement
 nuptialement néanmoins nébuleusement nécessairement néfastement négatif
 négligemment néologiquement névrotiquement nûment objectivement oblativement
 oblige obligeamment obliquement obrepticement obscurément obscènement
 obsessivement obstinément obséquieusement obtusément obèsement
 occultement octogonalement oculairement océanographiquement odieusement
 oenologiquement offensivement officiellement officieusement oiseusement
 olfactivement oligarchiquement ombrageusement onc oncques onctueusement
 oniriquement onomatopéiquement onques ontologiquement onzièmement onéreusement
 ophtalmologiquement opiniâtrement opportunistement opportunément opposément
 optimalement optimistement optionnellement optiquement opulemment
 opératoirement orageusement oralement oratoirement orbiculairement
 ordinairement ordurièrement ores organiquement organoleptiquement orgiaquement
 orgueilleusement orientalement originairement originalement originellement
 orographiquement orthodoxement orthogonalement orthographiquement
 orthopédiquement osmotiquement ostensiblement ostentatoirement oublieusement
 out outrageusement outrancièrement outre outre-atlantique outre-mer
 outrecuidamment ouvertement ovalement oviparement ovoviviparement
 pacifiquement paillardement pairement paisiblement palingénésiquement
 paléobotaniquement paléographiquement paléontologiquement panoptiquement
 pantagruéliquement papelardement paraboliquement paradigmatiquement
 paralittérairement parallactiquement parallèlement paramilitairement
 parasitairement parcellairement parcellement parcimonieusement pardon
 paresseusement parfaitement parfois parisiennement paritairement
 parodiquement paroxistiquement paroxystiquement partant parthénogénétiquement
 particulièrement partiellement partout pas passablement passagèrement passim
 passionnément passivement passé pastoralement pataudement patelinement
 paternellement paternement pathologiquement pathétiquement patibulairement
 patriarcalement patrilinéairement patrimonialement patriotiquement pauvrement
 païennement peinardement peineusement penaudement pendablement pendant
 pensivement pentatoniquement perceptiblement perceptivement perdurablement
 permissivement pernicieusement perpendiculairement perplexement
 persifleusement perso personnellement perspicacement persuasivement
 pertinemment perversement pesamment pessimistement petit petitement peu
 peut-être pharisaïquement pharmacologiquement philanthropement
 philistinement philologiquement philosophiquement phobiquement phoniquement
 phonologiquement phonématiquement phonémiquement phonétiquement
 photographiquement photométriquement phrénologiquement phylogénétiquement
 physiologiquement physionomiquement physiquement phénoménalement
 phénoménologiquement pianissimo pianistiquement piano pictographiquement
 pieusement pile pinailleusement pingrement piteusement pitoyablement
 piètrement più placidement plaignardement plaintivement plaisamment
 plantureusement planétairement plastiquement plat platement platoniquement
 plein pleinement pleutrement pluriannuellement pluridisciplinairement
 plurinationalement plus plutoniquement plutôt plébéiennement plénièrement
 pléthoriquement pneumatiquement point pointilleusement pointu poisseusement
 poliment polissonnement politiquement poltronnement polygonalement
 polyédriquement polémiquement pomologiquement pompeusement ponctuellement
 pontificalement populairement pornographiquement positionnellement
 possessivement possessoirement possiblement posthumement posthumément
 postérieurement posément potablement potentiellement pourquoi pourtant
 poétiquement pragmatiquement pratiquement premièrement presque prestement
 prestissimo presto primairement primesautièrement primitivement primo
 principalement princièrement printanièrement prioritairement privativement
 probablement probement problématiquement processionnellement prochainement
 proconsulairement prodigalement prodigieusement prodiguement productivement
 professionnellement professoralement profitablement profond profondément
 progressivement projectivement proleptiquement prolifiquement prolixement
 promptement pronominalement prophylactiquement prophétiquement propicement
 proportionnellement proportionnément proprement prosaïquement prosodiquement
 prospèrement protocolairement protohistoriquement prou proverbialement
 provincialement provisionnellement provisoirement prudement prudemment
 préalablement précairement précautionneusement précieusement précipitamment
 précisément précocement précédemment préférablement préférentiellement
 préjudiciablement préliminairement prélogiquement prématurément
 prépositivement préscolairement présentement présomptivement présomptueusement
 présumément prétendument prétentieusement préventivement prévisionnellement
 psychanalytiquement psychiatriquement psychiquement psycholinguistiquement
 psychométriquement psychopathologiquement psychophysiologiquement
 psychosomatiquement psychothérapiquement puamment publicitairement
 pudibondement pudiquement pugnacement puissamment pulmonairement
 purement puritainement pusillanimement putainement putassièrement putativement
 pyramidalement pyrométriquement pâlement pâteusement pécuniairement
 pédamment pédantement pédantesquement pédestrement péjorativement pénalement
 péniblement pénitentiairement pépèrement péremptoirement périlleusement
 périphériquement périscolairement pétrochimiquement pétrographiquement
 pêle-mêle quadrangulairement quadrimestriellement quadruplement
 quand quantitativement quarantièmement quarto quasi quasiment quater
 quatrièmement quellement quelque quelquefois question quinto quinzièmement
 quiètement quoique quotidiennement racialement racoleusement radiairement
 radicalement radieusement radinement radiographiquement radiologiquement
 radiotélégraphiquement radioélectriquement rageusement raidement railleusement
 rapacement rapidement rapido rapidos rarement rarissimement ras rasibus
 recevablement reconventionnellement recta rectangulairement rectilignement
 redoutablement regrettablement relativement religieusement remarquablement
 reproductivement représentativement respectablement respectivement
 restrictivement revêchement rhomboédriquement rhéologiquement rhétoriquement
 richissimement ridiculement rieusement rigidement rigoureusement rinforzando
 risiblement ritardando rituellement robustement rocailleusement
 rogatoirement roguement roidement romainement romancièrement romanesquement
 rond rondement rondouillardement rosement rossement rotativement roturièrement
 rougement routinièrement royalement rubato rudement rudimentairement
 ruralement rustaudement rustiquement rustrement rythmiquement
 réactionnairement réalistement rébarbativement récemment réciproquement
 rédhibitoirement réellement réflexivement réfractairement référendairement
 régionalement réglementairement réglo régressivement régulièrement
 répréhensiblement répulsivement répétitivement résidentiellement
 résineusement résolument rétivement rétroactivement rétrospectivement
 révocablement révolutionnairement révéremment révérencieusement rêveusement
 sacerdotalement sacramentellement sacrilègement sacrément sadiquement
 sagement sagittalement sainement saintement saisonnièrement salacement
 salaudement salement salubrement salutairement samedi sanguinairement
 saphiquement sarcastiquement sardoniquement sataniquement satiriquement
 satyriquement sauf saumâtrement sauvagement savamment savoureusement
 scalairement scandaleusement scatologiquement sceptiquement scherzando scherzo
 schématiquement sciemment scientifiquement scolairement scolastiquement
 sculpturalement scélératement scéniquement sec secondairement secondement
 secrètement sectairement sectoriellement secundo seigneurialement seizièmement
 semestriellement sempiternellement senestrorsum sensationnellement
 sensuellement sensément sentencieusement sentimentalement septentrionalement
 septièmement sereinement serré serviablement servilement seul seulement sexto
 sforzando si sibyllinement sic sidéralement sidérurgiquement significativement
 similairement simplement simultanément sincèrement singulièrement sinistrement
 sinon sinueusement siouxement sirupeusement sitôt sixièmement smorzando
 sobrement sociablement socialement sociolinguistiquement sociologiquement
 socratiquement soigneusement soit soixantièmement solairement soldatesquement
 solidairement solidement solitairement somatiquement sombrement sommairement
 somptuairement somptueusement songeusement sonorement sophistiquement
 sordidement sororalement sostenuto sottement soucieusement soudain
 souhaitablement souplement soupçonneusement sourcilleusement sourdement
 souterrainement souvent souventefois souverainement soyeusement spacieusement
 spasmodiquement spatialement spectaculairement spectralement sphériquement
 splendidement spontanément sporadiquement sportivement spécialement
 spécifiquement spéculairement spéculativement spéléologiquement stablement
 staliniennement stationnairement statiquement statistiquement statutairement
 stoechiométriquement stoïquement stratigraphiquement stratégiquement
 stridemment strophiquement structuralement structurellement studieusement
 stylistiquement sténographiquement stérilement stéréographiquement
 stéréophoniquement suavement subalternement subconsciemment subitement subito
 sublimement subordinément subordonnément subrepticement subrogatoirement
 substantiellement substantivement subséquemment subtilement subversivement
 succinctement succulemment suffisamment suggestivement suicidairement
 superbement superficiellement superfinement superfétatoirement superlativement
 supplémentairement supplétivement supportablement supposément supra
 suprêmement supérieurement surabondamment surhumainement surnaturellement
 surréellement surtout surérogatoirement sus suspectement suspicieusement
 syllabiquement syllogistiquement symbiotiquement symboliquement
 symphoniquement symptomatiquement symétriquement synchroniquement
 syndicalement synergiquement synonymiquement synoptiquement syntactiquement
 syntaxiquement synthétiquement systématiquement systémiquement sèchement
 séculièrement sédentairement séditieusement sélectivement sélénographiquement
 sémiologiquement sémiotiquement sémiquement séméiotiquement sénilement
 séquentiellement séraphiquement sériellement sérieusement sérologiquement
 sûr sûrement tabulairement tacitement taciturnement tactilement tactiquement
 talmudiquement tangentiellement tangiblement tant tantôt tapageusement
 tard tardivement tatillonnement tauromachiquement tautologiquement
 taxinomiquement taxonomiquement techniquement technocratiquement
 tectoniquement teigneusement tellement temporairement temporellement
 tenacement tendanciellement tendancieusement tendrement tennistiquement
 tenuto ter terminologiquement ternement terrible terriblement territorialement
 testimonialement texto textuellement thermiquement thermodynamiquement
 thermonucléairement thermoélectriquement thématiquement théocratiquement
 théologiquement théoriquement théosophiquement thérapeutiquement thétiquement
 timidement titulairement tièdement tiédassement tocardement tolérablement
 toniquement topiquement topographiquement topologiquement toponymiquement
 torrentueusement torridement tortueusement torvement totalement
 toujours touristiquement tout toute toutefois toxicologiquement
 traditionnellement tragediante tragiquement tranquillement
 transcendantalement transformationnellement transgressivement transitivement
 transversalement traumatologiquement traînardement traîtreusement
 trentièmement triangulairement tribalement tridimensionnellement
 trihebdomadairement trimestriellement triomphalement triplement
 tristement trivialement troisio troisièmement trompeusement trop
 très ttc tumultuairement tumultueusement turpidement tutélairement typiquement
 typologiquement tyranniquement télescopiquement téléautographiquement
 téléinformatiquement télématiquement téléologiquement télépathiquement
 télévisuellement témérairement ténébreusement tératologiquement tétaniquement
 tétraédriquement tôt ultimement ultimo ultérieurement unanimement uniformément
 unilinéairement uniment uninominalement unipolairement uniquement unitairement
 universitairement univoquement unièmement urbainement urgemment urologiquement
 usurairement utilement utilitairement utopiquement uvulairement vachardement
 vaginalement vaguement vaillamment vainement valablement valeureusement
 vaniteusement vantardement vaporeusement variablement vasculairement
 vasouillardement vastement velléitairement vendredi venimeusement ventralement
 verbeusement vernaculairement versatilement vertement verticalement
 vertueusement verveusement vestimentairement veulement vicieusement
 vieillottement vigesimo vigilamment vigoureusement vilain vilainement vilement
 vingtièmement violemment virginalement virilement virtuellement virulemment
 viscéralement visiblement visqueusement visuellement vitalement vite vitement
 vivacement vivement viviparement vocalement vocaliquement voir voire
 volcaniquement volcanologiquement volontairement volontiers volubilement
 voluptueusement voracement voyez-vous vrai vraiment vraisemblablement
 vulgo végétalement végétativement véhémentement vélairement vélocement
 véniellement vénéneusement vénérablement véracement véridiquement
 vésaniquement vétilleusement vétustement xylographiquement xérographiquement
 zootechniquement âcrement âprement çà échocardiographiquement
 échométriquement éclatamment éclectiquement écologiquement économement
 économétriquement édéniquement également égalitairement égocentriquement
 égrillardement éhontément élastiquement électivement électoralement
 électrocardiographiquement électrochimiquement électrodynamiquement
 électromagnétiquement électromécaniquement électroniquement
 électropneumatiquement électrostatiquement électrotechniquement
 éliminatoirement élitistement élogieusement éloquemment élégamment
 élémentairement éminemment émotionnellement émotivement énergiquement
 énigmatiquement énièmement énormément épais épaissement éparsement épatamment
 éphémèrement épicuriennement épidermiquement épidémiologiquement
 épigrammatiquement épigraphiquement épileptiquement épiquement épiscopalement
 épistolairement épistémologiquement épouvantablement équitablement
 équivoquement érotiquement éruditement éruptivement érémitiquement
 étatiquement éternellement éthiquement éthologiquement étonnamment étourdiment
 étroitement étymologiquement évangéliquement évasivement éventuellement
""".split())
